@@ -1,10 +1,18 @@
 <?php
 
-$dirgal=".";  # directory when the gallery directories are
+# FitGallery 0.80 copyleft GPL by Pollo (magura@ardilla.dyndns.org) and Presi (presi@confluencia.net)
+# http://fitgallery.presi.org
+
+# view thumbs page file
+
+include 'config-dirgal.php';
+include 'config.php';
+include 'config-lang.php';
+
+$version="0.80";
 $galeria=basename($_GET["galeria"]);
 $dirimgs="imgs";
 $semiruta=$dirgal."/".$galeria;
-$titulo="titulo";
 $lineas=file($semiruta."/".$titulo);
 $ruta=$semiruta."/".$dirimgs;
 $n=0;
@@ -13,70 +21,14 @@ $total=0;
 
 echo '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
       "http://www.w3.org/TR/html4/strict.dtd">
-<!-- FitGallery 0.75 copyleft GPL Pollo (magura@ardilla.dyndns.org) y Presi (presi@confluencia.net) -->
+<!-- FitGallery 0.80 copyleft GPL by Pollo and Presi http://fitgallery.presi.org -->
 <html>
 <head>
 <style type="text/css">
-<!--
-div.figure
-{
-  float: left;
-  border: thin red solid;
-  margin: 0.3em;
-  padding: 0.3em;
-  text-align: center;
-}
-p.caption
-{
-  font-size: smaller;
-  text-indent: 0;
-}
-p.clear
-{ 
-  clear: left;
-  text-align: center;
-}
-p.center,h3.center,h4.center
-{ 
-  text-align: center;
-}
-img.sinborde
-{
-  border-style: none;
-}
-a.texto
-{
-  color: #0000ff;
-}
-
-a.texto:visited       
-{               
-  color: #660066;
-}               
-
-a.texto:active
-{
-  color: #ff0000;
-}
-
-a.texto:hover
-{
-  color: #0000ff;
-  background: #ffffcc;
-}
-body
-{
-';
-if (mt_rand(0,1)) $c_r="d";
-else $c_r="f";
-if (mt_rand(0,1)) $c_g="d";
-else $c_g="e";
-if (mt_rand(0,1)) $c_b="d";
-else $c_b="e";
-echo '  background: #'.$c_r.'0'.$c_g.'0'.$c_b.'0; 
-  color: #000000;
-}
--->
+<!--';
+if (file_exists('ver_thumb.css.php')) { include 'ver_thumb.css.php'; }
+else { include 'default.css.php'; }
+echo '-->
 </style>
 <title>'.$lineas[0].'</title>
 </head>
@@ -107,7 +59,6 @@ $para=$_GET["para"];
 if ($para=='' || !is_numeric($para) || $para<0 || $para>$numero_arch) $para=0;
 $para=intval($para);
 
-$avance=12;                # numero de fotos que saldrn por pagina
 $desde=$para+1;
 $avmenosuno=$avance-1;
 $hasta=$desde+$avmenosuno;
@@ -127,10 +78,14 @@ for ( $i=$para ; $i <= $para2 ; $i++)
 
    echo "
    <div class=\"figure\">
+   <p class=\"caption\">
    <a href=\"$ruta/$valor\">
-   <img class=\"sinborde\" src=\"thumb.php?galeria=$galeria&amp;valor=$valor\" alt=\"$valor\">
-   </a>
-   <p class=\"caption\">";
+   <img class=\"sinborde\" src=\"thumb.php?galeria=$galeria&amp;valor=$valor&amp;horiz=$h_thumb&amp;tipo=t\" alt=\"$valor\">
+   </a>";
+   if ($h_medium>0) 
+     echo "<br><a class=\"texto\" href=\"thumb.php?galeria=$galeria&amp;valor=$valor&amp;horiz=$h_medium&amp;tipo=m\">$text_medium</a>";
+   echo "</p>";
+   echo "<p class=\"caption\">";
    echo $i+1;
    echo ". ";
    echo "<a class=\"texto\" href=\"$ruta/$valor\">
@@ -147,11 +102,10 @@ for ( $i=$para ; $i <= $para2 ; $i++)
 $numer_pag=$nummenosuno/$avance;
 settype($numer_pag, "integer");
 
-echo '
-<p class="clear">
+echo "
+<p class=\"clear\">
 <br>
-<strong>Galer&iacute;as: </strong>
-';
+<strong>$text_galerias</strong>";
 
 for ($i = 1, $cuenta=$avance, $cuentaant=1; $i <= $numer_pag; $i++)
 {
@@ -175,21 +129,24 @@ echo '</p>
 ';
 $anterior=$para-$avance;
 $siguiente=$para+$avance;
-if ($anterior<0) echo "Anterior";
-            else echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$anterior\">Anterior</a>";
+if ($anterior<0) echo $text_anterior;
+            else echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$anterior\">$text_anterior</a>";
 print " | ";
-if ($siguiente>$cuentaantmenosuno) echo "Siguiente";
-            else echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$siguiente\">Siguiente</a>";
+if ($siguiente>$cuentaantmenosuno) echo $text_siguiente;
+            else echo "<a class=\"texto\" href=\"ver_thumb.php?galeria=$galeria&amp;para=$siguiente\">$text_siguiente</a>";
 echo "</p>
 <p class=\"center\">
-Total bytes: $total ($totalmegas MB)
+$text_totales$total ($totalmegas MB)
 </p>
 <p class=\"center\">
 <a href=\"http://validator.w3.org/check/referer\">
 <img class=\"sinborde\" src=\"valid-html401.png\" alt=\"Valid HTML 4.01!\" height=\"31\" width=\"88\">
 </a>
-</p>
-</body>
+</p>";
+
+if (powered) echo "<p class=\"center\">$text_powered<a href=\"http://fitgallery.presi.org\">FitGallery $version</a></p>";
+
+echo "</body>
 </html>";
 
 ?>
